==> v0.1.0.tar.gz: wp-git-action/README.md <==
# wp-git-action

Woodpecker CI plugin to execute git actions

[![Build Status](https://ci.thegeeklab.de/api/badges/thegeeklab/wp-git-action/status.svg)](https://ci.thegeeklab.de/repos/thegeeklab/wp-git-action)
[![Docker Hub](https://img.shields.io/badge/dockerhub-latest-blue.svg?logo=docker&logoColor=white)](https://hub.docker.com/r/thegeeklab/wp-git-action)
[![Quay.io](https://img.shields.io/badge/quay-latest-blue.svg?logo=docker&logoColor=white)](https://quay.io/repository/thegeeklab/wp-git-action)
[![Go Report Card](https://goreportcard.com/badge/github.com/thegeeklab/wp-git-action)](https://goreportcard.com/report/github.com/thegeeklab/wp-git-action)
[![GitHub contributors](https://img.shields.io/github/contributors/thegeeklab/wp-git-action)](https://github.com/thegeeklab/wp-git-action/graphs/contributors)
[![Source: GitHub](https://img.shields.io/badge/source-github-blue.svg?logo=github&logoColor=white)](https://github.com/thegeeklab/wp-git-action)
[![License: Apache-2.0](https://img.shields.io/github/license/thegeeklab/wp-git-action)](https://github.com/thegeeklab/wp-git-action/blob/main/LICENSE)

Woodpecker CI plugin to execute git actions. You can find the full documentation at [https://wp-plugin-index.geekdocs.de](https://wp-plugin-index.geekdocs.de/plugins/wp-git-action).

## Contributors

Special thanks to all [contributors](https://github.com/thegeeklab/wp-git-action/graphs/contributors). If you would like to contribute, please see the [instructions](https://github.com/thegeeklab/wp-git-action/blob/main/CONTRIBUTING.md).

## License

This project is licensed under the Apache-2.0 License - see the [LICENSE](https://github.com/thegeeklab/wp-git-action/blob/main/LICENSE) file for details.

==> v0.1.2.tar.gz: wp-git-action/README.md <==
# wp-git-action

Woodpecker CI plugin to perform git actions

[![Build Status](https://ci.thegeeklab.de/api/badges/thegeeklab/wp-git-action/status.svg)](https://ci.thegeeklab.de/repos/thegeeklab/wp-git-action)
[![Docker Hub](https://img.shields.io/badge/dockerhub-latest-blue.svg?logo=docker&logoColor=white)](https://hub.docker.com/r/thegeeklab/wp-git-action)
[![Quay.io](https://img.shields.io/badge/quay-latest-blue.svg?logo=docker&logoColor=white)](https://quay.io/repository/thegeeklab/wp-git-action)
[![Go Report Card](https://goreportcard.com/badge/github.com/thegeeklab/wp-git-action)](https://goreportcard.com/report/github.com/thegeeklab/wp-git-action)
[![GitHub contributors](https://img.shields.io/github/contributors/thegeeklab/wp-git-action)](https://github.com/thegeeklab/wp-git-action/graphs/contributors)
[![Source: GitHub](https://img.shields.io/badge/source-github-blue.svg?logo=github&logoColor=white)](https://github.com/thegeeklab/wp-git-action)
[![License: Apache-2.0](https://img.shields.io/github/license/thegeeklab/wp-git-action)](https://github.com/thegeeklab/wp-git-action/blob/main/LICENSE)

Woodpecker CI plugin to perform git actions. You can find the full documentation at [https://wp-plugin-index.geekdocs.de](https://wp-plugin-index.geekdocs.de/plugins/wp-git-action).

## Contributors

Special thanks to all [contributors](https://github.com/thegeeklab/wp-git-action/graphs/contributors). If you would like to contribute, please see the [instructions](https://github.com/thegeeklab/wp-git-action/blob/main/CONTRIBUTING.md).

## License

This project is licensed under the Apache-2.0 License - see the [LICENSE](https://github.com/thegeeklab/wp-git-action/blob/main/LICENSE) file for details.
